@@ -1,16 +1,28 @@
 #' Get database summary
 #'
 #' @description Get a summary of the data stored.
+#' 
+#' @param triplestore Object of class triplestore_access which manages database
+#' access.
 #'
 #' @return Data frame: Columns: "data type", "value".
 #' 
 #' @examples 
 #' 
-#' get_db_summary()
+#' triplestore <- triplestore_access$new()
+#' 
+#' triplestore$set_access_options(
+#'   url = "https://graphdb.fortunalab.org",
+#'   user = "public_avida",
+#'   password = "public_avida",
+#'   repository = "avidaDB_test"
+#' )
+#' 
+#' get_db_summary(triplestore)
 #'
 #' @export
 #' 
-get_db_summary <- function()
+get_db_summary <- function(triplestore)
 {
   # Get summary
   abstract <- triplestore$submit_query("PREFIX terms: <http://purl.org/dc/terms/>
