@@ -5,24 +5,45 @@
 #'
 #' @param genome_seq String of letters or a list of strings
 #' 
+#' @param triplestore Object of class triplestore_access which manages database
+#' access.
+#' 
 #' @return Data frame. Columns: "genome_id" "genome_seq"
 #' 
 #' @examples
-#' # Get sequence for genome_1
-#' sequence <- get_genome_seq_from_genome_id(genome_id = 1)$genome_seq[1]
 #' 
-#' #
-#' get_genome_id_from_genome_seq(genome_seq = sequence)
+#' # Create triplestore object
+#' triplestore <- triplestore_access$new()
+#' 
+#' # Set access options
+#' triplestore$set_access_options(
+#'   url = "https://graphdb.fortunalab.org",
+#'   user = "public_avida",
+#'   password = "public_avida",
+#'   repository = "avidaDB_test"
+#' )
+#' 
+#' # Get sequence for genome_1
+#' sequence <- get_genome_seq_from_genome_id(
+#'   genome_id = 1,
+#'   triplestore = triplestore
+#' )$genome_seq[1]
+#' 
+#' # Get genome id from sequence
+#' get_genome_id_from_genome_seq(
+#'   genome_seq = sequence,
+#'   triplestore = triplestore
+#' )
 #' 
 #' @export
 
-get_genome_id_from_genome_seq <- function(genome_seq) {
+get_genome_id_from_genome_seq <- function(genome_seq, triplestore) {
   # validata params
   validate_param(param = "genome_seq", value = genome_seq, types = 3)
 
   # Build query
   query <- paste0("
-    PREFIX ONTOAVIDA: <", ontoavida_prefix, ">
+    PREFIX ONTOAVIDA: <", ontoavida_prefix(), ">
     SELECT distinct ?genome_id ?genome_seq WHERE {
         # genome
         #genome_seq_triple#
@@ -37,7 +58,7 @@ get_genome_id_from_genome_seq <- function(genome_seq) {
 
   if (nrow(response) > 0) {
     # Remove prefixes
-    response <- remove_prefix(prefix = ontoavida_prefix, data = response)
+    response <- remove_prefix(prefix = ontoavida_prefix(), data = response)
   }
 
   # Return response
