@@ -6,25 +6,42 @@
 #'
 #' @param genome_id  Integer or a list of integer values.
 #' 
+#' @param triplestore Object of class triplestore_access which manages database
+#' access.
+#' 
 #' @return Data frame. Columns: "genome_id" "genome_seq"
 #' 
 #' @examples 
 #' 
+#' # Create triplestore object
+#' triplestore <- triplestore_access$new()
+#' 
+#' # Set access options
+#' triplestore$set_access_options(
+#'   url = "https://graphdb.fortunalab.org",
+#'   user = "public_avida",
+#'   password = "public_avida",
+#'   repository = "avidaDB_test"
+#' )
+#' 
 #' # Single genome
-#' get_genome_seq_from_genome_id(1)
+#' get_genome_seq_from_genome_id(1, triplestore = triplestore)
 #' 
 #' # More than one genome
-#' get_genome_seq_from_genome_id(genome_id = c(1, 2, 3, 4))
+#' get_genome_seq_from_genome_id(
+#'   genome_id = c(1, 2, 3, 4),
+#'   triplestore = triplestore
+#' )
 #'
 #' @export
 
-get_genome_seq_from_genome_id <- function(genome_id) {
+get_genome_seq_from_genome_id <- function(genome_id, triplestore) {
   # Validate params
   validate_param(param = "genome_id", value = genome_id, types = 2)
 
   # Build query
   query <- paste0("
-    PREFIX ONTOAVIDA: <", ontoavida_prefix, ">
+    PREFIX ONTOAVIDA: <", ontoavida_prefix(), ">
     SELECT distinct ?genome_id ?genome_seq WHERE {
         # genome
         #genome#
@@ -40,7 +57,7 @@ get_genome_seq_from_genome_id <- function(genome_id) {
 
   if (nrow(response) > 0) {
     # Remove prefixes
-    response <- remove_prefix(prefix = ontoavida_prefix, data = response)
+    response <- remove_prefix(prefix = ontoavida_prefix(), data = response)
   }
 
   # Return response
