@@ -5,38 +5,61 @@
 #' for starting the pseudo-random number generator (i.e., a set of environments).
 #'
 #' @param phenotype_id Integer or list of integer values.
+#' 
 #' @param seed_id Integer (from 1 to 1000) or a vector of integer values. This
 #' integer is used for starting the pseudo-random number generator that
 #' represents the environment experiencing a digital organism. If seed_id value
 #' is not specified, it returns data for a single randomly chosen seed_id value
 #' (between 1 and 1000).
+#' 
 #' @param tandem_seq Logical value (TRUE/FALSE) to show/hide this column
 #' (FALSE by default).
+#' 
 #' @param tandem_pos Logical value (TRUE/FALSE) to show/hide this column
 #' (FALSE by default).
 #' 
+#' @param triplestore Object of class triplestore_access which manages database
+#' access.
 #'
 #' @return Data frame. Column: "seed_id" (optional), "phenotype_id",
 #' "tandem_id", "tandem_seq" (optional), "tandem_pos (optional)."
 #'
 #' @examples 
 #' 
+#' # Create triplestore object
+#' triplestore <- triplestore_access$new()
+#' 
+#' # Set access options
+#' triplestore$set_access_options(
+#'   url = "https://graphdb.fortunalab.org",
+#'   user = "public_avida",
+#'   password = "public_avida",
+#'   repository = "avidaDB_test"
+#' )
+#' 
 #' # Single phenotype
-#' get_tandem_id_from_phenotype_id(phenotype_id = 8, tandem_seq = TRUE)
+#' get_tandem_id_from_phenotype_id(
+#'   phenotype_id = 8, tandem_seq = TRUE,
+#'   triplestore = triplestore
+#' )
 #' 
 #' # More than one phenotype at seed_1
-#' get_tandem_id_from_phenotype_id(phenotype_id = c(2, 4, 8), seed_id = 1)
+#' get_tandem_id_from_phenotype_id(
+#'   phenotype_id = c(2, 4, 8), seed_id = 1,
+#'   triplestore = triplestore
+#' )
 #' 
 #' # At seed_1 and seed_2
 #' get_tandem_id_from_phenotype_id(
 #'   phenotype_id = 1,
 #'   seed_id = c(1, 2),
-#'   tandem_pos = TRUE
+#'   tandem_pos = TRUE,
+#'   triplestore = triplestore
 #' )
 #'
 #' @export
 
-get_tandem_id_from_phenotype_id <- function(phenotype_id, seed_id = sample(1:1000, 1), tandem_seq = FALSE, tandem_pos = FALSE) {
+get_tandem_id_from_phenotype_id <- function(phenotype_id, seed_id = sample(1:1000, 1), tandem_seq = FALSE, tandem_pos = FALSE, triplestore) {
   # Validate params
   validate_param(param = "phenotype_id", value = phenotype_id, types = 2)
   validate_param(param = "seed_id", value = seed_id, types = 2)
@@ -44,7 +67,7 @@ get_tandem_id_from_phenotype_id <- function(phenotype_id, seed_id = sample(1:100
   validate_param(param = "tandem_seq", value = tandem_seq, types = 1)
 
   # Build sparql query
-  query <- paste0("PREFIX ONTOAVIDA: <", ontoavida_prefix, ">\n",
+  query <- paste0("PREFIX ONTOAVIDA: <", ontoavida_prefix(), ">\n",
                   "PREFIX RO: <http://purl.obolibrary.org/obo/RO_>\n",
                   "PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>\n",
                   "select distinct  #encodes_at_seed_id# ?tandem_id #tandem_seq# #tandem_pos# ?phenotype_id {\n",
@@ -80,8 +103,8 @@ get_tandem_id_from_phenotype_id <- function(phenotype_id, seed_id = sample(1:100
 
   if (nrow(response) > 0) {
     # Remove prefixes
-    response <- remove_prefix(prefix = ontoavida_prefix, data = response)
-    response <- remove_prefix(prefix = rdf_prefix, data = response)
+    response <- remove_prefix(prefix = ontoavida_prefix(), data = response)
+    response <- remove_prefix(prefix = rdf_prefix(), data = response)
     response <- clean_at_seed_id (data = response, seed_id = seed_id, at_seed_vars = "encodes_at_seed_id")
     
     # Show/hide columns
