@@ -1,14 +1,25 @@
 test_that("get_genome_id_from_genome_seq", {
 
+  triplestore <- triplestore_access$new()
+  
+  triplestore$set_access_options(
+    url = "https://graphdb.fortunalab.org",
+    user = "public_avida",
+    password = "public_avida",
+    repository = "avidaDB_test"
+  )
+  
   sequence1 <- "acksdblwxnlhuxpjfmhcowivenwrcepkpwhcsdxzobuicloefcpsxpmovktqodgtpzursjelhdfxayfcvtdsqbloizzfgxypwoza"
   sequence2 <- "wakkoarhimcntsprxhcwpxvdvixzqkeezetmyvuvnwlxatoldiimqgtslvutvnquxefucqmkearisdaogqzbdywpbenlhdtwawtd"
 
   found1 <- get_genome_id_from_genome_seq(
-    genome_seq = sequence1
+    genome_seq = sequence1,
+    triplestore = triplestore
   )
 
   found2 <- get_genome_id_from_genome_seq(
-    genome_seq = c(sequence2, sequence1)
+    genome_seq = c(sequence2, sequence1),
+    triplestore = triplestore
   )
 
   expect_match(class(found1), "data.frame")
