@@ -1,16 +1,27 @@
 test_that("get_phenotype_id_from_genome_seq", {
 
+  triplestore <- triplestore_access$new()
+  
+  triplestore$set_access_options(
+    url = "https://graphdb.fortunalab.org",
+    user = "public_avida",
+    password = "public_avida",
+    repository = "avidaDB_test"
+  )
+  
   sequence1 <- "acksdblwxnlhuxpjfmhcowivenwrcepkpwhcsdxzobuicloefcpsxpmovktqodgtpzursjelhdfxayfcvtdsqbloizzfgxypwoza"
   sequence2 <- "wakkoarhimcntsprxhcwpxvdvixzqkeezetmyvuvnwlxatoldiimqgtslvutvnquxefucqmkearisdaogqzbdywpbenlhdtwawtd"
 
   found1 <- get_phenotype_id_from_genome_seq(
-    genome_seq = sequence1
+    genome_seq = sequence1,
+    triplestore = triplestore
   )
 
   found2 <- get_phenotype_id_from_genome_seq(
     genome_seq = c(sequence1, sequence2),
     seed_id = c(2, 1),
-    phenotype_binary = TRUE
+    phenotype_binary = TRUE,
+    triplestore = triplestore
   )
 
   expect_match(class(found1), "data.frame")
