@@ -1,22 +1,34 @@
 test_that("get_tandem_id_from_phenotype", {
 
+  triplestore <- triplestore_access$new()
+  
+  triplestore$set_access_options(
+    url = "https://graphdb.fortunalab.org",
+    user = "public_avida",
+    password = "public_avida",
+    repository = "avidaDB_test"
+  )
+  
   found1 <- get_tandem_id_from_phenotype_id(
     phenotype_id = 1,
-    seed_id = 1
+    seed_id = 1,
+    triplestore = triplestore
   )
 
   found2 <- get_tandem_id_from_phenotype_id(
     phenotype_id = c(1, 2),
     seed_id = c(2,1),
     tandem_seq = TRUE,
-    tandem_pos = FALSE
+    tandem_pos = FALSE,
+    triplestore = triplestore
   )
 
   found3 <- get_tandem_id_from_phenotype_id(
     phenotype_id = c(1, 2),
     seed_id = c(2,1),
     tandem_seq = FALSE,
-    tandem_pos = TRUE
+    tandem_pos = TRUE,
+    triplestore = triplestore
   )
 
   expect_match(class(found1), "data.frame")
