@@ -4,6 +4,6 @@ test_that("logic_operation", {
 
   expect_match(class(found1), "character")
   expect_true(length(found1) == 9)
-  expect_equal(found1, logic_operation_default)
+  expect_equal(found1, logic_operation_default())
   
 })
\ No newline at end of file
